@@ -4,14 +4,15 @@
 #' @param D1 matrix of tropical points; rows are points
 #' @param D2 matrix of tropical points; rows are points
 #' @return betweenness cluster measure
-#' @references David Barnhill, Ruriko Yoshida (2023). Clustering Methods Over the Tropically Convex Sets.
+#' @references David Barnhill, Ruriko Yoshida (2023). Clustering Methods Over
+#'   the Tropically Convex Sets.
 #' @author David Barnhill \email{david.barnhill@@nps.edu}
 #' @noRd
 
 trop_bet_dist<-function(D1,D2){
   dstar<-0
   for(i in 1:nrow(D2)){
-    pD2<-project_pi(D1,D2[i,])
+    pD2<-project.pi(D1,D2[i,])
     td<-trop.dist(D2[i,],pD2)
     dstar<-dstar+td
   }
