@@ -1,20 +1,24 @@
 #' Agglomerative (AGNES) tropical hierarchical clustering
 #'
-#' This function performs agglomerative (AGNES) hierarchical clustering over the space of ultrametrics defining the space of equidistant trees
+#' This function performs agglomerative (AGNES) hierarchical clustering over the
+#' space of ultrametrics defining the space of equidistant trees
 #'
-#' @param D matrix of points defining a tropical polytope.  Rows are the tropical points
-#' @param method linkage method: "average", "min", or "max"
-#' @return list of distances in when merges occur; list of indices of points in each cluster
+#' @param D matrix of points defining a tropical polytope.  Rows are the
+#'   tropical points
+#' @param method linkage method: mean, min, or max
+#' @return list of distances in when merges occur; list of indices of points in
+#'   each cluster
 #' @author David Barnhill \email{david.barnhill@@nps.edu}
-#' @references David Barnhill, Ruriko Yoshida (2023). Clustering Methods Over the Tropically Convex Sets.
+#' @references David Barnhill, Ruriko Yoshida (2023). Clustering Methods Over
+#'   the Tropically Convex Sets.
 #' @export
 #' @examples
 #' \donttest{P <-Sim_points
-#' Tropical.HC.AGNES(P, method="average")
+#' Tropical.HC.AGNES(P, method=mean)
 #' }
 
-Tropical.HC.AGNES <- function(D, method="average"){
-  ### method is one of "average", "min", "max"
+Tropical.HC.AGNES <- function(D, method=mean){
+  ### method is one of `mean`, `min`, `max`
   d <- dim(D)
   distance <- rep(0, d[1])
   index.list <- list()
